@@ -1,7 +1,7 @@
 package Perinci::Sub::To::CLIOptSpec;
 
-our $DATE = '2014-11-20'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2014-11-21'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,16 +15,20 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(gen_cli_opt_spec_from_meta);
 
-sub _get_cat_from_arg_spec {
-    my $arg_spec = shift;
+sub _add_category_from_arg_spec {
+    my ($opt, $arg_spec) = @_;
     my $cat;
+    my $raw_cat = '';
     for (@{ $arg_spec->{tags} // [] }) {
         if (!ref($_) && /^category:(.+)/) {
+            $raw_cat = $1;
             $cat = ucfirst($1) . " options";
             last;
         }
     }
     $cat //= "Options";
+    $opt->{category} = $cat;
+    $opt->{raw_category} = $raw_cat;
 }
 
 sub _add_default_from_arg_spec {
@@ -177,7 +181,7 @@ sub gen_cli_opt_spec_from_meta {
             delete $args_prop{$arg};
             $pos++;
         }
-        unshift @args, "[options]" if keys %args_prop; # XXX translatable?
+        unshift @args, "[options]" if keys(%args_prop) || keys(%$common_opts); # XXX translatable?
         $cliospec->{usage_line} = "[[prog]]".
             (@args ? " ".join(" ", @args) : "");
     }
@@ -213,73 +217,75 @@ sub gen_cli_opt_spec_from_meta {
             my $ospec = $ospecs->{$k};
             my $ok;
 
-            if ($ospec->{is_alias}) {
-                # non-groupable alias
+            if ($ospec->{is_alias} || defined($ospec->{arg})) {
+                my $arg_spec;
+                my $opt;
 
-                my $arg_spec = $args_prop->{ $ospec->{arg} };
-                my $alias_spec = $arg_spec->{cmdline_aliases}{$ospec->{alias}};
-                my $rimeta = rimeta($alias_spec);
-                $ok = _fmt_opt($arg_spec, $ospec);
-                my $opt = {
-                    arg_spec => $arg_spec,
-                    is_alias => 1,
-                    alias_for => $ospec->{alias_for},
-                    category => _get_cat_from_arg_spec($arg_spec),
-                    summary => $rimeta->langprop({lang=>$lang}, 'summary') //
-                        "Alias for "._dash_prefix($ospec->{parsed}{opts}[0]),
-                    description =>
+                if ($ospec->{is_alias}) {
+                    # non-groupable alias
+
+                    $arg_spec = $args_prop->{ $ospec->{arg} };
+                    my $alias_spec = $arg_spec->{cmdline_aliases}{$ospec->{alias}};
+                    my $rimeta = rimeta($alias_spec);
+                    $ok = _fmt_opt($arg_spec, $ospec);
+                    $opt = {
+                        is_alias => 1,
+                        alias_for => $ospec->{alias_for},
+                        summary => $rimeta->langprop({lang=>$lang}, 'summary') //
+                            "Alias for "._dash_prefix($ospec->{parsed}{opts}[0]),
+                        description =>
                         $rimeta->langprop({lang=>$lang}, 'description'),
-                };
-                _add_default_from_arg_spec($opt, $arg_spec);
-                $opts{$ok} = $opt;
-            } elsif (defined $ospec->{arg}) {
-                # an option for argument
-
-                my $arg_spec = $args_prop->{$ospec->{arg}};
-                my $rimeta = rimeta($arg_spec);
-                my $opt = {
-                    arg_spec => $arg_spec,
-                    category => _get_cat_from_arg_spec($arg_spec),
-                };
-
-                # for bool, only display either the positive (e.g. --bool) or
-                # the negative (e.g. --nobool) depending on the default
-                if (defined($ospec->{is_neg})) {
-                    my $default = $arg_spec->{default} //
-                        $arg_spec->{schema}[1]{default};
-                    next OSPEC2 if  $default && !$ospec->{is_neg};
-                    next OSPEC2 if !$default &&  $ospec->{is_neg};
-                    if ($ospec->{is_neg}) {
-                        next OSPEC2 if $negs{$ospec->{arg}}++;
-                    }
-                }
-
-                if ($ospec->{is_neg}) {
-                    # for negative option, use summary.alt.neg instead of
-                    # summary
-                    $opt->{summary} =
-                        $rimeta->langprop({lang=>$lang}, 'summary.alt.neg');
+                    };
                 } else {
-                    $opt->{summary} =
-                        $rimeta->langprop({lang=>$lang}, 'summary');
-                }
-                $opt->{description} =
-                    $rimeta->langprop({lang=>$lang}, 'description');
+                    # an option for argument
 
-                # find aliases that can be grouped together with this option
-                my @aliases;
-                my $j = $#k_aliases;
-                while ($j >= 0) {
-                    my $aospec = $ospecs->{ $k_aliases[$j] };
-                    {
-                        last unless $aospec->{arg} eq $ospec->{arg};
-                        push @aliases, $aospec;
-                        splice @k_aliases, $j, 1;
+                    $arg_spec = $args_prop->{$ospec->{arg}};
+                    my $rimeta = rimeta($arg_spec);
+                    my $opt = {};
+
+                    _add_category_from_arg_spec($opt, $arg_spec);
+
+                    # for bool, only display either the positive (e.g. --bool) or
+                    # the negative (e.g. --nobool) depending on the default
+                    if (defined($ospec->{is_neg})) {
+                        my $default = $arg_spec->{default} //
+                            $arg_spec->{schema}[1]{default};
+                        next OSPEC2 if  $default && !$ospec->{is_neg};
+                        next OSPEC2 if !$default &&  $ospec->{is_neg};
+                        if ($ospec->{is_neg}) {
+                            next OSPEC2 if $negs{$ospec->{arg}}++;
+                        }
                     }
-                    $j--;
+
+                    if ($ospec->{is_neg}) {
+                        # for negative option, use summary.alt.neg instead of
+                        # summary
+                        $opt->{summary} =
+                            $rimeta->langprop({lang=>$lang}, 'summary.alt.neg');
+                    } else {
+                        $opt->{summary} =
+                            $rimeta->langprop({lang=>$lang}, 'summary');
+                    }
+                    $opt->{description} =
+                        $rimeta->langprop({lang=>$lang}, 'description');
+
+                    # find aliases that can be grouped together with this option
+                    my @aliases;
+                    my $j = $#k_aliases;
+                    while ($j >= 0) {
+                        my $aospec = $ospecs->{ $k_aliases[$j] };
+                        {
+                            last unless $aospec->{arg} eq $ospec->{arg};
+                            push @aliases, $aospec;
+                            splice @k_aliases, $j, 1;
+                        }
+                        $j--;
+                    }
+
+                    $ok = _fmt_opt($arg_spec, $ospec, @aliases);
                 }
 
-                $ok = _fmt_opt($arg_spec, $ospec, @aliases);
+                $opt->{arg_spec} = $arg_spec;
 
                 # include keys from func.specmeta
                 for (qw/arg fqarg is_base64 is_json is_yaml/) {
@@ -287,13 +293,17 @@ sub gen_cli_opt_spec_from_meta {
                 }
 
                 # include keys from arg_spec
-                for (qw/req pos greedy is_password/) {
+                for (qw/req pos greedy is_password links tags/) {
                     $opt->{$_} = $arg_spec->{$_} if defined $arg_spec->{$_};
                 }
+
+                _add_category_from_arg_spec($opt, $arg_spec);
                 _add_default_from_arg_spec($opt, $arg_spec);
                 $opts{$ok} = $opt;
+
             } else {
                 # option from common_opts
+
                 $ok = _fmt_opt($common_opts, $ospec);
                 my $rimeta = rimeta($common_opts->{$ospec->{common_opt}});
                 $opts{$ok} = {
@@ -302,6 +312,7 @@ sub gen_cli_opt_spec_from_meta {
                     description =>
                         $rimeta->langprop({lang=>$lang}, 'description'),
                 };
+
             }
         }
     }
@@ -325,7 +336,7 @@ Perinci::Sub::To::CLIOptSpec - Generate data structure convenient for producing
 
 =head1 VERSION
 
-This document describes version 0.03 of Perinci::Sub::To::CLIOptSpec (from Perl distribution Perinci-Sub-To-CLIOptSpec), released on 2014-11-20.
+This document describes version 0.04 of Perinci::Sub::To::CLIOptSpec (from Perl distribution Perinci-Sub-To-CLIOptSpec), released on 2014-11-21.
 
 =head1 SYNOPSIS
 
